@@ -1,4 +1,3 @@
-
 #!/usr/bin/env python
 # encoding: utf-8
 """
@@ -7,7 +6,6 @@ tempodb/client.py
 Copyright (c) 2012 TempoDB, Inc. All rights reserved.
 """
 
-from dateutil import parser
 import re
 import requests
 import simplejson
@@ -15,6 +13,7 @@ import urllib
 import urllib2
 
 import tempodb
+from tempodb import DataPoint, DataSet, Series, Summary
 
 
 API_HOST = 'api.tempo-db.com'
@@ -25,90 +24,6 @@ VALID_SERIES_KEY = r'^[a-zA-Z0-9\.:;\-_]+$'
 RE_VALID_SERIES_KEY = re.compile(VALID_SERIES_KEY)
 
 
-class Database(object):
-
-    def __init__(self, key, secret):
-        self.key = key
-        self.secret = secret
-
-
-class Series(object):
-
-    def __init__(self, i, key, name="", attributes={}, tags=[]):
-        self.id = i
-        self.key = key
-        self.name = name
-        self.attributes = attributes
-        self.tags = tags
-
-    def to_json(self):
-        return self.__dict__
-
-    @staticmethod
-    def from_json(json):
-        i = json.get('id', '')
-        key = json.get('key', '')
-        attributes = json.get('attributes', {})
-        tags = json.get('tags', [])
-        name = json.get('name', '')
-        series = Series(i, key, name=name, attributes=attributes, tags=tags)
-        return series
-
-
-class DataPoint(object):
-
-    def __init__(self, ts, value):
-        self.ts = ts
-        self.value = value
-
-    def __str__(self):
-        return "t: %s, v: %s" % (self.ts, self.value)
-
-    def to_json(self):
-        json = {
-            't': self.ts.isoformat(),
-            'v': self.value,
-        }
-        return json
-
-    @staticmethod
-    def from_json(json):
-        ts = parser.parse(json.get('t', ''))
-        value = json.get('v', None)
-        dp = DataPoint(ts, value)
-        return dp
-
-
-class DataSet(object):
-
-    def __init__(self, series, start, end, data=[], summary=None):
-        self.series = series
-        self.start = start
-        self.end = end
-        self.data = data
-        self.summary = summary
-
-    @staticmethod
-    def from_json(json):
-        series = Series.from_json(json.get('series', {}))
-
-        start_date = parser.parse(json.get('start', ''))
-        end_date = parser.parse(json.get('end', ''))
-
-        data = [DataPoint.from_json(dp) for dp in json.get("data", [])]
-        summary = Summary.from_json(json.get('summary', {})) if 'summary' in json else None
-        return DataSet(series, start_date, end_date, data, summary)
-
-
-class Summary(object):
-
-    @staticmethod
-    def from_json(json):
-        summary = Summary()
-        summary.__dict__.update(json)
-        return summary
-
-
 class Client(object):
 
     def __init__(self, key, secret, host=API_HOST, port=API_PORT, secure=True):
@@ -117,6 +32,7 @@ class Client(object):
         self.host = host
         self.port = port
         self.secure = secure
+        self.session = requests.session()
 
     def create_database(self, name=""):
         params = {
@@ -195,6 +111,16 @@ class Client(object):
         series_val = series_key
         return self._read(series_type, series_val, start, end, interval, function, tz)
 
+    def delete_id(self, series_id, start, end, **kwargs):
+        series_type = 'id'
+        series_val = series_id
+        return self._delete(series_type, series_val, start, end, kwargs)
+
+    def delete_key(self, series_key, start, end, **kwargs):
+        series_type = 'key'
+        series_val = series_key
+        return self._delete(series_type, series_val, start, end, kwargs)
+
     def write_id(self, series_id, data):
         series_type = 'id'
         series_val = series_id
@@ -259,6 +185,16 @@ class Client(object):
             return json
         return DataSet.from_json(json)
 
+    def _delete(self, series_type, series_val, start, end, options):
+        params = {
+            'start': start.isoformat(),
+            'end': end.isoformat(),
+        }
+        params.update(options)
+        url = '/series/%s/%s/data/' % (series_type, series_val)
+        json = self.request(url, method='DELETE', params=params)
+        return json
+
     def _write(self, series_type, series_val, data):
         url = '/series/%s/%s/data/' % (series_type, series_val)
         body = [dp.to_json() for dp in data]
@@ -272,23 +208,27 @@ class Client(object):
         return json
 
     def request(self, target, method='GET', params={}):
-        assert method in ['GET', 'POST', 'PUT'], "Only 'GET' and 'POST' are allowed for method."
+        assert method in ['GET', 'POST', 'PUT', 'DELETE'], "Only 'GET', 'POST', 'PUT', 'DELETE' are allowed for method."
 
         headers = {
-            'User-Agent': 'tempodb-python/%s' % (tempodb.get_version(), )
+            'User-Agent': 'tempodb-python/%s' % (tempodb.get_version(), ),
+            'Accept-Encoding': 'gzip',
         }
 
         if method == 'POST':
             headers['Content-Type'] = "application/json"
             base = self.build_full_url(target)
-            response = requests.post(base, data=simplejson.dumps(params), auth=(self.key, self.secret), headers=headers)
+            response = self.session.post(base, data=simplejson.dumps(params), auth=(self.key, self.secret), headers=headers)
         elif method == 'PUT':
             headers['Content-Type'] = "application/json"
             base = self.build_full_url(target)
-            response = requests.put(base, data=simplejson.dumps(params), auth=(self.key, self.secret), headers=headers)
+            response = self.session.put(base, data=simplejson.dumps(params), auth=(self.key, self.secret), headers=headers)
+        elif method == 'DELETE':
+            base = self.build_full_url(target, params)
+            response = self.session.delete(base, auth=(self.key, self.secret), headers=headers)
         else:
             base = self.build_full_url(target, params)
-            response = requests.get(base, auth=(self.key, self.secret), headers=headers)
+            response = self.session.get(base, auth=(self.key, self.secret), headers=headers)
 
         if response.status_code == 200:
             if response.text:
